Crate stout_install

Crate stout_install 

stout-install: Package installation for stout

This crate handles:

  • Extracting bottles to Cellar
  • Building from source when bottles unavailable
  • Creating bottles from installed packages
  • Creating symlinks
  • Writing INSTALL_RECEIPT.json
  • Running post-install hooks
  • Parallel installation support

Re-exports

pub use cask_scan::count_caskroom_casks;
pub use cask_scan::register_cask_in_caskroom;
pub use cask_scan::scan_caskroom;
pub use cask_scan::unregister_cask_from_caskroom;
pub use cask_scan::InstalledBrewCask;
pub use cellar::count_cellar_packages;
pub use cellar::parse_brew_receipt;
pub use cellar::scan_cellar;
pub use cellar::scan_cellar_package;
pub use cellar::timestamp_to_iso;
pub use cellar::BrewReceipt;
pub use cellar::BrewRuntimeDep;
pub use cellar::CellarPackage;

Modules

cask_scan
Cask scanning - detect installed Homebrew casks from the Caskroom filesystem
cellar
Cellar scanning and Homebrew receipt parsing

Structs

BottleInfo
Information about a bottle to extract
BottleResult
Result of bottle creation
BuildConfig
Build configuration
BuildResult
Build result
HeadBuildConfig
Configuration for building from HEAD (git)
HeadBuildResult
Result of a HEAD build
HeadBuilder
Builder for HEAD (git) installations
InstallReceipt
INSTALL_RECEIPT.json structure (Homebrew compatible)
LinkInfo
Information about a package to link
PackageInstallResult
Result of a single package installation
ParallelConfig
Configuration for parallel installation
ParallelInstaller
Parallel installer for multiple packages
RuntimeDependency
SourceBuilder
Source builder for formulas

Enums

BuildError
Specific build errors with context
Error

Functions

can_build_from_source
Check if build from source is available for a formula
create_bottle
Create a bottle from an installed package
extract_bottle
Extract a bottle tarball to the Cellar
link_package
Link a package from Cellar to prefix
relocate_bottle
Relocate Homebrew placeholders in the extracted bottle
remove_package
Remove an installed package from the Cellar
scan_cellar_unrelocated
Scan all packages in a cellar directory for unresolved placeholders in parallel.
scan_unrelocated_files
Scan a directory for files containing unresolved @@HOMEBREW_*@@ placeholders.
unlink_package
Unlink a package
write_receipt
Write an INSTALL_RECEIPT.json file

Type Aliases

Result