stout-install: Package installation for stout
This crate handles:
- Extracting bottles to Cellar
- Building from source when bottles unavailable
- Creating bottles from installed packages
- Creating symlinks
- Writing INSTALL_RECEIPT.json
- Running post-install hooks
- Parallel installation support
Re-exports
pub use cask_scan::count_caskroom_casks;pub use cask_scan::register_cask_in_caskroom;pub use cask_scan::scan_caskroom;pub use cask_scan::unregister_cask_from_caskroom;pub use cask_scan::InstalledBrewCask;pub use cellar::count_cellar_packages;pub use cellar::parse_brew_receipt;pub use cellar::scan_cellar;pub use cellar::scan_cellar_package;pub use cellar::timestamp_to_iso;pub use cellar::BrewReceipt;pub use cellar::BrewRuntimeDep;pub use cellar::CellarPackage;
Modules
- cask_
scan - Cask scanning - detect installed Homebrew casks from the Caskroom filesystem
- cellar
- Cellar scanning and Homebrew receipt parsing
Structs
- Bottle
Info - Information about a bottle to extract
- Bottle
Result - Result of bottle creation
- Build
Config - Build configuration
- Build
Result - Build result
- Head
Build Config - Configuration for building from HEAD (git)
- Head
Build Result - Result of a HEAD build
- Head
Builder - Builder for HEAD (git) installations
- Install
Receipt - INSTALL_RECEIPT.json structure (Homebrew compatible)
- Link
Info - Information about a package to link
- Package
Install Result - Result of a single package installation
- Parallel
Config - Configuration for parallel installation
- Parallel
Installer - Parallel installer for multiple packages
- Runtime
Dependency - Source
Builder - Source builder for formulas
Enums
- Build
Error - Specific build errors with context
- Error
Functions
- can_
build_ from_ source - Check if build from source is available for a formula
- create_
bottle - Create a bottle from an installed package
- extract_
bottle - Extract a bottle tarball to the Cellar
- link_
package - Link a package from Cellar to prefix
- relocate_
bottle - Relocate Homebrew placeholders in the extracted bottle
- remove_
package - Remove an installed package from the Cellar
- scan_
cellar_ unrelocated - Scan all packages in a cellar directory for unresolved placeholders in parallel.
- scan_
unrelocated_ files - Scan a directory for files containing unresolved @@HOMEBREW_*@@ placeholders.
- unlink_
package - Unlink a package
- write_
receipt - Write an INSTALL_RECEIPT.json file